@@ -9,15 +9,16 @@ use Parse::CPAN::Whois;
 use Path::Extended::Dir;
 use Path::Extended::File;
 use File::Spec;
-use LWP::Simple;
+use LWP::UserAgent;
 use JSON;
 use URI;
 use URI::QueryParam;
 use version;
 use CPAN::Meta::YAML;
 use CPAN::DistnameInfo;
+use IO::Zlib;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 sub new {
   my ($class, %args) = @_;
@@ -37,6 +38,11 @@ sub new {
 
   $args{pid} = $$;
 
+  $args{ua} ||= LWP::UserAgent->new(
+    agent => "WorePAN/$VERSION",
+    env_proxy => 1,
+  );
+
   my $self = bless \%args, $class;
 
   my @files = @{ delete $self->{files} || [] };
@@ -132,8 +138,12 @@ sub _dists2files {
       map { $dists->{$_} ? "$_,$dists->{$_}" : $_ } @tmp
     ]);
     $self->_log("called API: $uri");
-    my $res = get($uri) or return;
-    my $rows = eval { JSON::decode_json($res) };
+    my $res = $self->{ua}->get($uri);
+    if ($res->is_error) {
+      warn "API error: $uri ".$res->status_line;
+      return;
+    }
+    my $rows = eval { JSON::decode_json($res->decoded_content) };
     if ($@) {
       warn $@;
       return;
@@ -177,15 +187,13 @@ sub __fetch {
   if (!$self->{no_network}) {
     my $url = $self->{cpan}."authors/id/$file";
     $self->_log("mirror $url to $dest");
-    if (!is_error(mirror($url => $dest))) {
-      return $dest;
-    }
+    my $res = $self->{ua}->mirror($url => $dest);
+    return $dest if $res->is_success;
     if ($self->{backpan}) {
       my $url = $self->{backpan}."authors/id/$file";
       $self->_log("mirror $url to $dest");
-      if (!is_error(mirror($url => $dest))) {
-        return $dest;
-      }
+      my $res = $self->{ua}->mirror($url => $dest);
+      return $dest if $res->is_success;
     }
   }
   warn "Can't fetch $file\n";
